@@ -219,7 +219,7 @@ Deletes an argument we were passing to our template.
 =head2 show $component
 
 Display the presentation component.  If not specified, use the
-default page in call_next.
+request path as the default page.
 
 =head2 dispatch $path
 
@@ -722,26 +722,10 @@ sub _do_show {
     $path = "$self->{cwd}/$path" unless $path =~ m{^/};
 
     # When we're requesting a directory, go looking for the index.html
-    if ( $path =~ m{/$} and $self->template_exists( $path . "/index.html" ) )
-    {
-
+    if ( $self->template_exists( $path . "/index.html" ) ) {
         $path .= "/index.html";
     }
 
-    # Redirect to directory (and then index) if they requested
-    # the directory itself
-
-    # XXX TODO, we should search all component roots
-
-    if ($path !~ m{/$}
-        and -d Jifty::Util->absolute_path(
-            Jifty->config->framework('Web')->{'TemplateRoot'} . $path
-        )
-        )
-    {
-        $self->_do_show( $path . "/" );
-    }
-
     my $abs_template_path = Jifty::Util->absolute_path(
         Jifty->config->framework('Web')->{'TemplateRoot'} . $path );
     my $abs_root_path = Jifty::Util->absolute_path(
