@@ -31,12 +31,17 @@ BEGIN {
     # Creating a new CGI object breaks FastCGI in all sorts of painful
     # ways.  So wrap the call and preempt it if we already have one
     use CGI ();
-    *CGI::__jifty_real_new = \&CGI::new;
-    
-    no warnings qw(redefine);
-    *CGI::new = sub {
-	return Jifty->handler->cgi if Jifty->handler->cgi;
-	CGI::__jifty_real_new(@_);	
+
+    # If this file gets reloaded using Module::Refresh, don't do this
+    # magic again, or we'll get infinite recursion
+    unless (CGI->can('__jifty_real_new')) {
+        *CGI::__jifty_real_new = \&CGI::new;
+
+        no warnings qw(redefine);
+        *CGI::new = sub {
+            return Jifty->handler->cgi if Jifty->handler->cgi;
+            CGI::__jifty_real_new(@_);	
+        }
     }
 };
 
@@ -64,6 +69,7 @@ sub new {
         Jifty->config->framework('ApplicationClass') . "::Dispatcher" );
     Jifty::Util->require( $self->dispatcher );
     $self->dispatcher->import_plugins;
+    $self->dispatcher->dump_rules;
 
     $self->mason( Jifty::View::Mason::Handler->new( $self->mason_config ) );
 
@@ -179,21 +185,23 @@ sub handle_request {
     # Build a new stash for the life of this request
     $self->stash({});
     local $HTML::Mason::Commands::JiftyWeb = Jifty::Web->new();
-    Jifty->web->request( Jifty::Request->new()->fill( $self->cgi ) );
 
-    Jifty->web->response( Jifty::Response->new );
     Jifty->web->setup_session;
+    Jifty->web->request( Jifty::Request->new()->fill( $self->cgi ) );
+    Jifty->web->response( Jifty::Response->new );
     Jifty->web->session->set_cookie;
     Jifty->api->reset;
     $_->new_request for Jifty->plugins;
 
     Jifty->log->debug( "Received request for " . Jifty->web->request->path );
-
     my $sent_response = 0;
     $sent_response
         = $self->static_handler->handle_request( Jifty->web->request->path )
         if ( Jifty->config->framework('Web')->{'ServeStaticFiles'} );
 
+    # Return from the continuation if need be
+    Jifty->web->request->return_from_continuation;
+
     $self->dispatcher->handle_request() unless ($sent_response);
 
     $self->cleanup_request();
