@@ -41,6 +41,12 @@ sub new {
 Finds the moniker of the first action of type I<ACTION> whose
 "constructor" field I<FIELD1> is I<VALUE1>, and so on.
 
+   my $mon =$mech->moniker_for('BTDT::Action::UpdateTask');
+
+If there is only one action of type ACTION, be sure not to pass
+any more arguments to this method, or the method will return undef.
+
+
 =cut
 
 sub moniker_for {
@@ -56,7 +62,7 @@ sub moniker_for {
         my $moniker = $1;
 
         for my $id (keys %args) {
-          my $idfield = $f->find_input("J:A:F:F:F-$id-$moniker");
+          my $idfield = $f->find_input("J:A:F:F-$id-$moniker");
           next INPUT unless $idfield and $idfield->value eq $args{$id};
         }
 
