@@ -16,6 +16,7 @@ use CGI::Cookie;
 use XML::Writer;
 use CSS::Squish;
 use Digest::MD5 qw(md5_hex);
+use Carp qw(carp);
 use base qw/Class::Accessor::Fast Class::Data::Inheritable Jifty::Object/;
 
 use vars qw/$SERIAL @JS_INCLUDES/;
@@ -61,6 +62,7 @@ __PACKAGE__->javascript_libs([qw(
     yui/calendar.js
     app.js
     app_behaviour.js
+    css_browser_selector.js                                 
 )]);
 
 =head1 METHODS
@@ -104,35 +106,44 @@ sub out {
 =head3 url
 
 Returns the root url of this Jifty application.  This is pulled from
-the configuration file.  Takes an optional named parameter C<scheme>
-to specify the scheme.
+the configuration file.  Takes an optional named path which will
+form the path part of the resulting URL.
 
 =cut
 
 sub url {
     my $self = shift;
-    my %args = @_;
+    my %args = (scheme => undef,
+                path => undef,
+                @_);
 
-    my $url  = Jifty->config->framework("Web")->{BaseURL};
-    my $port = Jifty->config->framework("Web")->{Port};
+    if ($args{'scheme'}) {
+        $self->log->error("Jifty->web->url no longer accepts a 'scheme' argument");
+    }
     
-    my $scheme = 'http';
-    if ($url =~ /^(\w+)/) {
-        $scheme = $1;
-    }
-    $scheme = $args{scheme} if $args{scheme};
-
+    my $uri;
     if ($ENV{'HTTP_HOST'}) {
-        return $scheme ."://".$ENV{'HTTP_HOST'};
+      my $host = $ENV{HTTP_HOST};
+      if ($host !~ m{^http://}) {
+        $host = 'http://' . $host;
+      }
+      $uri = URI->new($host);
+    } else {
+      my $url  = Jifty->config->framework("Web")->{BaseURL};
+      my $port = Jifty->config->framework("Web")->{Port};
+   
+      $uri = URI->new($url);
+      $uri->port($port);
     }
 
-    my $append_port = 0;
-    if (   ( $scheme  eq 'http' and $port != 80 )
-        or ( $scheme  eq'https' and $port != 443 ) ) {
-        $append_port = 1;
+    if (defined $args{path}) {
+      my $path = $args{path};
+      # strip off leading '/' because ->canonical provides one
+      $path =~ s{^/}{};
+      $uri->path($path);
     }
-    return( $url . ($append_port ? ":$port" : ""));
-
+    
+    return $uri->canonical->as_string;
 }
 
 =head3 serial 
@@ -542,7 +553,7 @@ sub redirect_required {
     }
 }
 
-=head3 redirect [URL]
+=head3 redirect [TO]
 
 Redirect to the next page. If you pass this method a parameter, it
 redirects to that URL rather than B<next_page>.
@@ -559,7 +570,7 @@ sub redirect {
     $page = Jifty::Web::Form::Clickable->new( url => $page )
       unless ref $page and $page->isa("Jifty::Web::Form::Clickable");
 
-    warn "Don't include GET paramters in the redirect URL -- use a Jifty::Web::Form::Clickable instead.  See L<Jifty::Web/redirect>" if $page->url =~ /\?/;
+    carp "Don't include GET paramters in the redirect URL -- use a Jifty::Web::Form::Clickable instead.  See L<Jifty::Web/redirect>" if $page->url =~ /\?/;
 
     my %overrides = ( @_ );
     $page->parameter($_ => $overrides{$_}) for keys %overrides;
@@ -698,7 +709,7 @@ L<Jifty::Web::Form::Clickable> object generated by the I<PARAMHASH>.
 sub goto {
     my $self = shift;
     Jifty->web->redirect(
-        Jifty::Web::Form::Clickable->new(@_)->complete_url );
+        Jifty::Web::Form::Clickable->new(@_));
 }
 
 =head3 link PARAMHASH
@@ -738,8 +749,9 @@ sub return {
 
 =head3 render_messages [MONIKER]
 
-Outputs any messages that have been added, in a <div id="messages">
-tag.  Messages are added by calling L<Jifty::Result/message>.
+Outputs any messages that have been added, in <div id="messages"> and
+<div id="errors"> tags.  Messages are added by calling
+L<Jifty::Result/message>.
 
 If a moniker is specified, only messages for that moniker 
 are rendered.
@@ -747,36 +759,87 @@ are rendered.
 
 =cut
 
-# XXX TODO factor out error and message rendering as separate
-
 sub render_messages {
     my $self = shift;
     my $only_moniker = '';
     $only_moniker = shift if (@_);
+
+    $self->render_error_messages($only_moniker);
+    $self->render_success_messages($only_moniker);
+
+    return '';
+}
+
+=head3 render_success_messages [MONIKER]
+
+Render success messages for the given moniker, or all of them if no
+moniker is given.
+
+=cut
+
+sub render_success_messages {
+    my $self = shift;
+    my $moniker = shift;
+
+    $self->_render_messages('message', $moniker);
+
+    return '';
+}
+
+=head3 render_error_messages [MONIKER]
+
+Render error messages for the given moniker, or all of them if no
+moniker is given.
+
+=cut
+
+sub render_error_messages {
+    my $self = shift;
+    my $moniker = shift;
+
+    $self->_render_messages('error', $moniker);
+
+    return '';
+}
+
+=head3 _render_messages TYPE [MONIKER]
+
+Output any messages of the given TYPE (either 'error' or 'message') in
+a <div id="TYPEs"> tag. If a moniker is given, only renders messages
+for that action. Internal helper for L</render_success_messages> and
+L</render_errors>.
+
+=cut
+
+sub _render_messages {
+    my $self = shift;
+    my $type = shift;
+    my $only_moniker = shift || '';
+
     my %results = $self->response->results;
 
-    return '' unless %results;
+    %results = ($only_moniker => $results{$only_moniker}) if $only_moniker;
 
-    my @monikers = ($only_moniker) || sort keys %results;
-
-    for my $type (qw(error message)) {
-        next unless grep { defined $results{$_}  and $results{$_}->$type() } @monikers;
-
-        my $plural = $type . "s";
-        $self->out(qq{<div id="$plural">});
-        $self->out(qq[<a id="dismiss_$plural" href="#"
-                         onclick="Effect.Fade(this.parentNode); return false;">]
-                   ._('Dismiss').qq[</a>]);
-        foreach my $moniker ( @monikers ) {
-            if ( $results{$moniker}->$type() ) {
-                $self->out( qq{<div class="$type $moniker">}
-                    . $results{$moniker}->$type()
-                    . qq{</div>} );
-            }
+    return unless grep {$_->$type()} values %results;
+    
+    my $plural = $type . "s";
+    $self->out(qq{<div id="$plural">});
+    
+    $self->out( qq[<a id="dismiss_$plural" href="#" title="]
+               .  _('Dismiss')
+               .qq[" onmousedown="this.onfocus=this.blur;" onmouseup="this.onfocus=window.clientInformation?null:window.undefined" ]
+               .qq[ onclick="Effect.Fade(this.parentNode); return false;">]
+               .  _('Dismiss')
+               .qq[</a>]);
+               
+    foreach my $moniker ( keys %results ) {
+        if ( $results{$moniker}->$type() ) {
+            $self->out( qq{<div class="$type $moniker">}
+                        . $results{$moniker}->$type()
+                        . qq{</div>} );
         }
-        $self->out(qq{</div>});
     }
-    return '';
+    $self->out(qq{</div>});
 }
 
 =head3 query_string KEY => VALUE [, KEY => VALUE [, ...]]
