@@ -3,7 +3,7 @@ package Jifty::Web::Menu;
 use base qw/Class::Accessor::Fast/;
 use URI;
 
-__PACKAGE__->mk_accessors(qw(label parent sort_order link escape_label));
+__PACKAGE__->mk_accessors(qw(label parent sort_order link escape_label class));
 
 =head2 new PARAMHASH
 
@@ -43,6 +43,10 @@ Gets or set a Jifty::Web::Link object that represents this menu item. If
 you're looking to do complex ajaxy things with menus, this is likely
 the option you want.
 
+=head2 class [STRING]
+
+Gets or sets the CSS class the link should have in addition to the default
+classes.  This is only used if C<link> isn't specified.
 
 =head2 url
 
@@ -101,23 +105,21 @@ sub child {
                                                         escape_label => 1,
                                                         @_
                                                        });
-    # Activate it
-    if (my $url = $self->{children}{$key}->url) {
-    # XXX TODO cleanup for mod_perl
-    my $base_path = Jifty->web->request->path;
-    chomp($base_path);
+        # Activate it
+        if (my $url = $self->{children}{$key}->url and Jifty->web->request) {
+            # XXX TODO cleanup for mod_perl
+            my $base_path = Jifty->web->request->path;
+            chomp($base_path);
         
-    $base_path =~ s/index\.html$//g;
-    $base_path =~ s/\/+$//g;
-    $url =~ s/\/+$//i;
-    if ($url eq $base_path) {
-        $self->{children}{$key}->active(1); 
+            $base_path =~ s/index\.html$//g;
+            $base_path =~ s/\/+$//g;
+            $url =~ s/\/+$//i;
+    
+            if ($url eq $base_path) {
+                $self->{children}{$key}->active(1); 
+            }
+	    }
     }
-	}
-
-}
-
-
 
     return $self->{children}{$key}
 }
@@ -263,7 +265,8 @@ sub as_link {
     } elsif ( $self->url ) {
         return Jifty->web->link( label => _( $self->label ),
                                  url   => $self->url,
-                                 escape_label => $self->escape_label );
+                                 escape_label => $self->escape_label,
+                                 class => $self->class );
     } else {
         return _( $self->label );
     }
